@@ -1,5 +1,6 @@
 import os
 import pyblish.backend.plugin
+import pyblish.backend.config
 
 # Setup
 HOST = 'python'
@@ -8,11 +9,12 @@ FAMILY = 'test.family'
 registered = pyblish.backend.plugin.registered_paths
 package_path = pyblish.backend.lib.main_package_path()
 plugin_path = os.path.join(package_path, 'backend', 'tests', 'plugins')
+pyblish.backend.plugin.deregister_all()
+pyblish.backend.config.paths[:] = []
 
 
 def setup():
     """Disable default plugins and only use test plugins"""
-    pyblish.backend.plugin.deregister_all()
     pyblish.backend.plugin.register_plugin_path(plugin_path)
 
 
@@ -26,14 +28,21 @@ def setup_failing():
 
 
 def setup_duplicate():
-    """Expose duplicate paths to discovery mechanism"""
+    """Expose duplicate plugins to discovery mechanism"""
     pyblish.backend.plugin.deregister_all()
+    pyblish.backend.config.paths[:] = []
 
     for copy in ('copy1', 'copy2'):
         path = os.path.join(plugin_path, 'duplicate', copy)
         pyblish.backend.plugin.register_plugin_path(path)
 
 
+def setup_invalid():
+    """Expose invalid plugins to discovery mechanism"""
+    failing_path = os.path.join(plugin_path, 'invalid')
+    pyblish.backend.plugin.register_plugin_path(failing_path)
+
+
 def teardown():
     """Restore previously registered paths"""
     pyblish.backend.plugin.deregister_all()
